export { VERSION } from "./init.js";
export type { ConstructorOf, PartialBy } from "./types.js";
export type { TypedArray, TypedArrayConstructor, NumberArray, BigIntOrNumberArray } from "./types.js";
export { isTypedArray, isNumberArray } from "./utils/is-array.js";
export { luma } from "./lib/luma.js";
export type { DeviceProps, DeviceInfo, DeviceFeature } from "./adapter/device.js";
export { Device, DeviceFeatures, DeviceLimits } from "./adapter/device.js";
export type { CanvasContextProps } from "./adapter/canvas-context.js";
export { CanvasContext } from "./adapter/canvas-context.js";
export type { ResourceProps } from "./adapter/resources/resource.js";
export { Resource } from "./adapter/resources/resource.js";
export type { BufferProps } from "./adapter/resources/buffer.js";
export { Buffer } from "./adapter/resources/buffer.js";
export type { TextureProps, TextureData } from "./adapter/resources/texture.js";
export { Texture } from "./adapter/resources/texture.js";
export type { TextureViewProps } from "./adapter/resources/texture-view.js";
export { TextureView } from "./adapter/resources/texture-view.js";
export type { ExternalTextureProps } from "./adapter/resources/external-texture.js";
export { ExternalTexture } from "./adapter/resources/external-texture.js";
export type { ShaderProps } from "./adapter/resources/shader.js";
export { Shader } from "./adapter/resources/shader.js";
export type { SamplerProps, SamplerParameters } from "./adapter/resources/sampler.js";
export { Sampler } from "./adapter/resources/sampler.js";
export type { FramebufferProps } from "./adapter/resources/framebuffer.js";
export { Framebuffer } from "./adapter/resources/framebuffer.js";
export type { RenderPipelineProps } from "./adapter/resources/render-pipeline.js";
export { RenderPipeline } from "./adapter/resources/render-pipeline.js";
export type { RenderPassProps } from "./adapter/resources/render-pass.js";
export { RenderPass } from "./adapter/resources/render-pass.js";
export type { ComputePipelineProps } from "./adapter/resources/compute-pipeline.js";
export { ComputePipeline } from "./adapter/resources/compute-pipeline.js";
export type { ComputePassProps } from "./adapter/resources/compute-pass.js";
export { ComputePass } from "./adapter/resources/compute-pass.js";
export type { CommandEncoderProps } from "./adapter/resources/command-encoder.js";
export { CommandEncoder } from "./adapter/resources/command-encoder.js";
export type { CommandBufferProps } from "./adapter/resources/command-buffer.js";
export { CommandBuffer } from "./adapter/resources/command-buffer.js";
export type { VertexArrayProps } from "./adapter/resources/vertex-array.js";
export { VertexArray } from "./adapter/resources/vertex-array.js";
export type { TransformFeedbackProps, BufferRange } from "./adapter/resources/transform-feedback.js";
export { TransformFeedback } from "./adapter/resources/transform-feedback.js";
export type { QuerySetProps } from "./adapter/resources/query-set.js";
export { QuerySet } from "./adapter/resources/query-set.js";
export type { AccessorObject } from "./adapter/types/accessor.js";
export type { Parameters, PrimitiveTopology, IndexFormat, CullMode, FrontFace, RasterizationParameters, CompareFunction, StencilOperation, DepthStencilParameters, BlendFactor, BlendOperation, ColorParameters, MultisampleParameters, RenderPassParameters, RenderPipelineParameters, PolygonMode, ProvokingVertex } from "./adapter/types/parameters.js";
export type { VertexFormat, VertexType } from "./adapter/types/vertex-formats.js";
export type { TextureFormat, ColorTextureFormat, DepthStencilTextureFormat } from "./adapter/types/texture-formats.js";
export type { ShaderDataType, ShaderAttributeType, ShaderUniformType } from "./adapter/types/shader-types.js";
export type { ColorAttachment, DepthStencilAttachment } from "./adapter/types/types.js";
export type { ShaderLayout, ComputeShaderLayout, AttributeDeclaration, BindingDeclaration, Binding } from "./adapter/types/shader-layout.js";
export type { BufferLayout, BufferAttributeLayout } from "./adapter/types/buffer-layout.js";
export type { AttributeBinding, UniformBinding, UniformBlockBinding, VaryingBinding } from "./adapter/types/shader-layout.js";
export type { UniformValue } from "./adapter/types/types.js";
export { UniformBufferLayout } from "./lib/uniforms/uniform-buffer-layout.js";
export { UniformBlock } from "./lib/uniforms/uniform-block.js";
export { UniformStore } from "./lib/uniforms/uniform-store.js";
export { decodeVertexFormat } from "./adapter/type-utils/decode-vertex-format.js";
export { decodeTextureFormat } from "./adapter/type-utils/decode-texture-format.js";
export { getDataTypeFromTypedArray, getTypedArrayFromDataType, getVertexFormatFromAttribute } from "./adapter/type-utils/vertex-format-from-attribute.js";
export { decodeShaderUniformType } from "./adapter/type-utils/decode-shader-types.js";
export { decodeShaderAttributeType } from "./adapter/type-utils/decode-attribute-type.js";
export type { CompilerMessage } from "./lib/compiler-log/compiler-message.js";
export { formatCompilerLog } from "./lib/compiler-log/format-compiler-log.js";
export type { AttributeInfo } from "./adapter/attribute-utils/get-attribute-from-layouts.js";
export { getAttributeInfosFromLayouts, mergeShaderLayout } from "./adapter/attribute-utils/get-attribute-from-layouts.js";
export { StatsManager } from "./utils/stats-manager.js";
export { assert } from "./utils/assert.js";
export { cast } from "./utils/cast.js";
export { log } from "./utils/log.js";
export { uid, isObjectEmpty } from "./utils/utils.js";
export { isUniformValue, splitUniformsAndBindings } from "./lib/uniforms/uniform.js";
export { formatValue } from "./utils/format-value.js";
export { stubRemovedMethods } from "./utils/stub-methods.js";
export { checkProps } from "./utils/check-props.js";
export { setPathPrefix, loadFile, loadImage, loadImageBitmap, loadScript } from "./utils/load-file.js";
export { getScratchArrayBuffer, getScratchArray, fillArray } from "./utils/array-utils-flat.js";
export { makeRandomNumberGenerator, random } from "./utils/random.js";
export { deepEqual } from "./utils/deep-equal.js";
export { requestAnimationFrame, cancelAnimationFrame } from "./utils/request-animation-frame.js";
/**
 * Marks GLSL shaders for syntax highlighting: glsl`...`
 * Install https://marketplace.visualstudio.com/items?itemName=boyswan.glsl-literal
 */
export declare const glsl: (x: TemplateStringsArray) => string;
export type { CopyBufferToBufferOptions, CopyBufferToTextureOptions, CopyTextureToBufferOptions, CopyTextureToTextureOptions } from "./adapter/resources/command-encoder.js";
//# sourceMappingURL=index.d.ts.map